summaryrefslogtreecommitdiffstats
path: root/models/issue_comment.go
diff options
context:
space:
mode:
authorLunny Xiao <xiaolunwen@gmail.com>2017-10-02 00:52:35 +0800
committerLauris BH <lauris@nix.lv>2017-10-01 19:52:35 +0300
commita8717e5e3ace4dd226547faae9c3a44616bbf6f0 (patch)
tree524dc024dec64131406486556951a53655ad8510 /models/issue_comment.go
parent1ad902d5298202d5be14fd5a9c8ed6ce781a23c8 (diff)
downloadgitea-a8717e5e3ace4dd226547faae9c3a44616bbf6f0.tar.gz
gitea-a8717e5e3ace4dd226547faae9c3a44616bbf6f0.zip
Use AfterLoad instead of AfterSet on Structs (#2628)
* use AfterLoad instead of AfterSet on Structs * fix the comments on AfterLoad * fix the comments on action AfterLoad
Diffstat (limited to 'models/issue_comment.go')
-rw-r--r--models/issue_comment.go37
1 files changed, 16 insertions, 21 deletions
diff --git a/models/issue_comment.go b/models/issue_comment.go
index 084a2a81b1..25d6535752 100644
--- a/models/issue_comment.go
+++ b/models/issue_comment.go
@@ -112,30 +112,25 @@ type Comment struct {
ShowTag CommentTag `xorm:"-"`
}
-// AfterSet is invoked from XORM after setting the value of a field of this object.
-func (c *Comment) AfterSet(colName string, _ xorm.Cell) {
+// AfterLoad is invoked from XORM after setting the values of all fields of this object.
+func (c *Comment) AfterLoad(session *xorm.Session) {
+ c.Created = time.Unix(c.CreatedUnix, 0).Local()
+ c.Updated = time.Unix(c.UpdatedUnix, 0).Local()
+
var err error
- switch colName {
- case "id":
- c.Attachments, err = GetAttachmentsByCommentID(c.ID)
- if err != nil {
- log.Error(3, "GetAttachmentsByCommentID[%d]: %v", c.ID, err)
- }
+ c.Attachments, err = getAttachmentsByCommentID(session, c.ID)
+ if err != nil {
+ log.Error(3, "getAttachmentsByCommentID[%d]: %v", c.ID, err)
+ }
- case "poster_id":
- c.Poster, err = GetUserByID(c.PosterID)
- if err != nil {
- if IsErrUserNotExist(err) {
- c.PosterID = -1
- c.Poster = NewGhostUser()
- } else {
- log.Error(3, "GetUserByID[%d]: %v", c.ID, err)
- }
+ c.Poster, err = getUserByID(session, c.PosterID)
+ if err != nil {
+ if IsErrUserNotExist(err) {
+ c.PosterID = -1
+ c.Poster = NewGhostUser()
+ } else {
+ log.Error(3, "getUserByID[%d]: %v", c.ID, err)
}
- case "created_unix":
- c.Created = time.Unix(c.CreatedUnix, 0).Local()
- case "updated_unix":
- c.Updated = time.Unix(c.UpdatedUnix, 0).Local()
}
}